@@ -48,6 +48,19 @@ sipd_sitrep <- function(survey = NULL) {
     former <- purrr::map2_lgl(cran, local, `>`)
     infos <- tibble::tibble(package=deps, cran=cran %>% purrr::map_chr(as.character), local=local %>% purrr::map_chr(as.character), former=former)
   }
+  else if (toupper(survey) == "PNDS") {
+    message("The PNDSIBGE package is under development and will be available soon.")
+    return(NULL)
+    deps <- unique(sort(c("PNDSIBGE", unlist(SIPDIBGE::sipd_deps(survey="PNDS")))))
+    base <- c("base", "compiler", "datasets", "graphics", "grDevices", "grid", "methods", "parallel", "splines", "stats", "stats4", "tools", "tcltk", "utils")
+    deps <- setdiff(deps, base)
+    tool <- c("cli", "crayon", "rstudioapi")
+    deps <- setdiff(deps, tool)
+    cran <- lapply(packs[deps, "Version"], package_version)
+    local <- lapply(deps, utils::packageVersion)
+    former <- purrr::map2_lgl(cran, local, `>`)
+    infos <- tibble::tibble(package=deps, cran=cran %>% purrr::map_chr(as.character), local=local %>% purrr::map_chr(as.character), former=former)
+  }
   else if (toupper(survey) == "PNS") {
     deps <- unique(sort(c("PNSIBGE", unlist(SIPDIBGE::sipd_deps(survey="PNS")))))
     base <- c("base", "compiler", "datasets", "graphics", "grDevices", "grid", "methods", "parallel", "splines", "stats", "stats4", "tools", "tcltk", "utils")
@@ -59,17 +72,19 @@ sipd_sitrep <- function(survey = NULL) {
     former <- purrr::map2_lgl(cran, local, `>`)
     infos <- tibble::tibble(package=deps, cran=cran %>% purrr::map_chr(as.character), local=local %>% purrr::map_chr(as.character), former=former)
   }
-  # else if (toupper(survey) == "POF") {
-  #   deps <- unique(sort(c("POFIBGE", unlist(SIPDIBGE::sipd_deps(survey="POF")))))
-  #   base <- c("base", "compiler", "datasets", "graphics", "grDevices", "grid", "methods", "parallel", "splines", "stats", "stats4", "tools", "tcltk", "utils")
-  #   deps <- setdiff(deps, base)
-  #   tool <- c("cli", "crayon", "rstudioapi")
-  #   deps <- setdiff(deps, tool)
-  #   cran <- lapply(packs[deps, "Version"], package_version)
-  #   local <- lapply(deps, utils::packageVersion)
-  #   former <- purrr::map2_lgl(cran, local, `>`)
-  #   infos <- tibble::tibble(package=deps, cran=cran %>% purrr::map_chr(as.character), local=local %>% purrr::map_chr(as.character), former=former)
-  # }
+  else if (toupper(survey) == "POF") {
+    message("The POFIBGE package was archived due to the impossibility of restructuring the files related to the survey microdata.")
+    return(NULL)
+    deps <- unique(sort(c("POFIBGE", unlist(SIPDIBGE::sipd_deps(survey="POF")))))
+    base <- c("base", "compiler", "datasets", "graphics", "grDevices", "grid", "methods", "parallel", "splines", "stats", "stats4", "tools", "tcltk", "utils")
+    deps <- setdiff(deps, base)
+    tool <- c("cli", "crayon", "rstudioapi")
+    deps <- setdiff(deps, tool)
+    cran <- lapply(packs[deps, "Version"], package_version)
+    local <- lapply(deps, utils::packageVersion)
+    former <- purrr::map2_lgl(cran, local, `>`)
+    infos <- tibble::tibble(package=deps, cran=cran %>% purrr::map_chr(as.character), local=local %>% purrr::map_chr(as.character), former=former)
+  }
   else {
     deps <- unique(sort(c(sipd_packages(), unlist(SIPDIBGE::sipd_deps()))))
     base <- c("base", "compiler", "datasets", "graphics", "grDevices", "grid", "methods", "parallel", "splines", "stats", "stats4", "tools", "tcltk", "utils")
